#!/usr/bin/env python3
from setuptools import find_packages, setup
import os

try:
    here = os.path.abspath(os.path.dirname(__file__))
    with open(os.path.join(here, 'README.md'), encoding='utf-8') as readme:
        long_description = readme.read()
except:
    pass

setup(
    name='jdTranslationHelper',
    version='1.1',
    description='A simple API for translating your programs.',
    long_description="Look at the Homepage for the documentation",
    url='https://gitlab.com/JakobDev/jdTranslationHelper',
    author='JakobDev',
    classifiers=[
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 3',
    ],
    keywords='translation localization JakobDev ',
    packages=find_packages(),
)



import locale
import os

class jdTranslationHelper():
    def __init__(self,lang=None,defaultLanguage="en_GB"):
        self.selectedLanguage = lang or locale.getlocale()[0]
        self.defaultLanguage = defaultLanguage
        self.strings = {}

    def readLanguageFile(self,path):
        with open(path,"r",encoding="utf-8") as f:
            lines = f.read().splitlines()
            for line in lines:
                try:
                    key, value = line.split("=",1)
                    self.strings[key] = value
                except:
                    print("Error loading line \"" + line + "\" in file " + path)

    def loadDirectory(self,path):
        if not os.path.isfile(os.path.join(path,self.defaultLanguage + ".lang")):
            print(path + " was not found")
            return
        self.readLanguageFile(os.path.join(path,self.defaultLanguage + ".lang"))
        if os.path.isfile(os.path.join(path,self.selectedLanguage + ".lang")):
            self.readLanguageFile(os.path.join(path,self.selectedLanguage + ".lang"))

    def translate(self,key,default=None):
        if key in self.strings:
            return self.strings[key]
        else:
            if default:
                return default
            else:
                return key
